@@ -39,6 +39,17 @@ class BaseAuthMiddleware:
 
         return exempt_patterns
 
+    @cached_property
+    def exempt_session_url_patterns(self):
+        exempt_patterns = set()
+        patterns = getattr(settings, "SESSION_CHECK_EXEMPT_URLS", [])
+
+        for url_pattern in patterns:
+            if isinstance(url_pattern, Pattern):
+                exempt_patterns.add(url_pattern)
+
+        return exempt_patterns 
+
     def _is_processable(self, request):
         pass
 
@@ -89,8 +100,9 @@ class LoginMiddleware(BaseAuthMiddleware, MiddlewareMixin):
         if user:
             user.backend = "dnoticias_auth.backends.ExtraClaimsOIDCAuthenticationBackend"
             auth.login(request, user)
+            session_id = request.COOKIES.get(get_cookie_equivalency("keycloak_session_id"))
 
-            if session_id := request.COOKIES.get(get_cookie_equivalency("keycloak_session_id")):
+            if session_id:
                 keycloak_session = KeycloakSessionStorage(session_id, request.session.session_key)
                 keycloak_session.create_or_update()
 
@@ -102,14 +114,12 @@ class LoginMiddleware(BaseAuthMiddleware, MiddlewareMixin):
 
     def process_request(self, request):
         if not self._is_processable(request):
-            logger.debug("The request is not processable, skipping...")
             return
 
         cookies = request.COOKIES
         session = request.session
 
         if not cookies.get(get_cookie_equivalency('oidc_access_token'), None):
-            logger.debug("Access token not found in cookie, skipping...")
             return
     
         # Setting the session items from cookies
@@ -176,6 +186,7 @@ class TokenMiddleware(BaseAuthMiddleware, MiddlewareMixin):
         """
         return (
             not any(pat.match(request.path) for pat in self.exempt_url_patterns)\
+            and not any(pat.match(request.path) for pat in self.exempt_session_url_patterns)\
             and not request.user.is_authenticated\
             and request.COOKIES.get("sessionid")
         )
@@ -199,18 +210,19 @@ class TokenMiddleware(BaseAuthMiddleware, MiddlewareMixin):
         """
         cookies = request.COOKIES
         session_id = cookies.get("sessionid")
-        dcs_session_api = settings.DCS_SESSION_MIGRATE_API_URL
+        has_dcs_session_api = getattr(settings, "DCS_SESSION_MIGRATE_API_URL", False)
 
         # If we dont have a session_id cookie, we just return the initial response
-        if not session_id:
+        if not session_id or not has_dcs_session_api:
             return http_response
 
+        dcs_session_api = getattr(settings, "DCS_SESSION_MIGRATE_API_URL")
         # We ask to the DCS the email associated to that session_id. This returns an email if the
         # sessionid is not anon, the user does not have @dnoticias.pt in his email and is not part
         # of the staff or superuser.
         response = requests.post(dcs_session_api, {"session_id": session_id})
         body = response.json()
-        logger.info("[DCS Session] Returned %s", body)
+        logger.debug("[DCS Session] Returned %s", body)
 
         if response.status_code == 200:
             if not body.get("error"):
