@@ -6,6 +6,7 @@ from django.views.decorators.csrf import csrf_exempt
 from django.utils.decorators import method_decorator
 from django.views.generic import View, FormView
 from django.shortcuts import render, redirect
+from django import VERSION as DJANGO_VERSION
 from django.urls import reverse_lazy
 from django.conf import settings
 from django.http import Http404
@@ -64,9 +65,10 @@ class DnoticiasOIDCLogoutView(OIDCLogoutView):
         the authentication cookies
         """
         keycloak_session_id = request.session.get("keycloak_session_id")
+        cookies: dict = request.COOKIES
 
         if not keycloak_session_id:
-            keycloak_session_id = request.COOKIES.get(get_cookie_equivalency("keycloak_session_id"))
+            keycloak_session_id = cookies.get(get_cookie_equivalency("keycloak_session_id"))
 
         delete_user_sessions(keycloak_session_id)
         super().post(request)
@@ -74,10 +76,15 @@ class DnoticiasOIDCLogoutView(OIDCLogoutView):
         # Response is defined first because we need to delete the cookies before redirect
         response = HttpResponseRedirect(self.redirect_url)
         auth_cookies = get_cookie_equivalency(all_names=True)
-        extra = {
-            "domain": settings.AUTH_COOKIE_DOMAIN,
-            "samesite": "Strict"
-        }
+
+        # This will delete any cookie with session_ (session_editions, session_comments, etc)
+        [auth_cookies.update({cookie: cookie}) for cookie in cookies.keys() if "session_" in cookie]
+
+        extra = {"domain": settings.AUTH_COOKIE_DOMAIN}
+
+        # Fix compatibility issues with django < 2 (CMS)
+        if DJANGO_VERSION[0] == 3:
+            extra.update({"samesite": "Strict"})
 
         # Deletes ONLY the cookies that we need
         [response.delete_cookie(cookie, **extra) for _, cookie in auth_cookies.items()]
